@@ -1,10 +1,8 @@
 import os
 
-import plumbum
-
 from devassistant import exceptions
 from devassistant import settings
-from devassistant.command_helpers import ClHelper, PathHelper, RPMHelper, YUMHelper
+from devassistant.command_helpers import ClHelper, PathHelper
 
 class AssistantBase(object):
     """WARNING: if assigning subassistants in __init__, make sure to override it
@@ -99,27 +97,8 @@ class AssistantBase(object):
         """
         pass
 
-    def _install_dependencies(self, *dep_list, **kwargs):
-        to_install = []
-
-        for dep in dep_list:
-            if dep.startswith('@'):
-                if not YUMHelper.is_group_installed(dep):
-                    to_install.append(dep)
-            else:
-                if not RPMHelper.is_rpm_installed(dep):
-                    to_install.append(dep)
-
-        if to_install: # only invoke YUM if we actually have something to install
-            if not YUMHelper.install(*to_install):
-                raise exceptions.RunException('Failed to install: {0}'.format(' '.join(to_install)))
-
-        for pkg in to_install:
-            RPMHelper.was_rpm_installed(pkg)
-
     def _git_create_repo(self, path, gitignore, **kwargs):
         PathHelper.cp(gitignore, path)
-        with plumbum.local.cwd(os.path.abspath(os.path.expanduser(path))):
-            ClHelper.run_command('git init')
-            ClHelper.run_command('git add .')
-            ClHelper.run_command('git commit -m "Initial commit."')
+        ClHelper.run_command('git init')
+        ClHelper.run_command('git add .')
+        ClHelper.run_command('git commit -m "Initial commit."')
