@@ -1,5 +1,5 @@
-COMMAND_LOG_STRING = '[devassistant]$ {cmd}'
-COMMAND_OUTPUT_STRING = '| {line}'
+COMMAND_LOG_STRING = u'[devassistant]$ {cmd}'
+COMMAND_OUTPUT_STRING = u'| {line}'
 LOG_LEVELS_MAP = {'d': 'DEBUG', 'i': 'INFO', 'w': 'WARNING', 'e': 'ERROR', 'c': 'CRITICAL'}
 SUBASSISTANT_PREFIX = 'subassistant'
 SUBASSISTANT_N_STRING = 'subassistant_{0}'
